==> mediawiki_1.15.3.orig.tar.gz: mediawiki-1.15.3/languages/messages/MessagesEml.php <==
<?php
/** Emiliano-Romagnolo (Emiliàn e rumagnòl)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ottaviano II
 * @author Timichal
 * @author Tèstaquêdra
 */

$fallback = 'it';

$messages = array(
# Dates
'sunday'    => 'Dmànga',
'monday'    => 'Lonedè',
'tuesday'   => 'Martedè',
'wednesday' => 'Merculdè',
'thursday'  => 'Giuvidè',
'friday'    => 'Venerdè',
'saturday'  => 'Sâbet',
'january'   => 'Znèr',
'february'  => 'Febrèr',
'march'     => 'Mèrz',
'april'     => 'Avrîl',
'june'      => 'Zógn',
'july'      => 'Lój',
'august'    => 'Agòst',
'september' => 'Setàmber',
'october'   => 'Utóber',
'november'  => 'Nuvàmber',
'december'  => 'Dzèmber',
'may'       => 'Mâz',

'qbspecialpages' => 'Pagini specièli',
'mytalk'         => 'I mê discussiòun',

'returnto'         => 'Tórna a $1.',
'help'             => 'Per quî rivê da pôch',
'history_short'    => 'Stôria',
'printableversion' => 'Versiòun stampàbil',
'permalink'        => 'Link permanèint',
'edit'             => 'Mudifichèr',
'delete'           => 'Dscanzèla',
'protect'          => 'Prutèzz',
'specialpage'      => 'Pàgina specièla',
'talk'             => 'Discussiòun',
'jumptosearch'     => 'Zerca',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'     => 'Fât e prugèt ed tót',
'currentevents-url' => 'Project:Prugèt_ed_tót',
'helppage'          => 'Help:Introduzione',
'portal'            => 'Discóter e quistiunêr',
'portal-url'        => 'Project:Bar',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Artéccol',
'nstab-template' => 'Modèl',

# Login and logout pages
'logouttext'           => "'''Adèsa s'et discunnês.'''

Putiv cuntinuèr ad usèr {{SITENAME}} anonimamèint, o putiv cunnètterv dòp cun al stèss nàmm o cun un èter.
Nutêv ca alcuni pàgini i putrèbber cuntinuèr a cràdder ca vueter a-sîv discunnès, finchè non purghê la cache dal vòster browser.",
'userlogin'            => 'Entrèr / Argistrères',
'logout'               => 'va fôra',
'userlogout'           => 'Va fôra',
'userexists'           => "Al nòmm ch'èt scélt l'è stê bèle usê: càten un èter, per piasêr.",
'yourrealname'         => 'Al tô vér nàmm:',
'yourlanguage'         => 'Léngua:',
'loginsuccess'         => "'''Adèsa sèt cunês in {{SITENAME}} cun al nàmm d'utèint \"\$1\".'''",
'wrongpassword'        => "La password ch'et méss l'è sbajèda. Pròva ancàrra.",
'blocked-mailpassword' => "Al tô indirézz IP l'an pôl più feèr di cambiamèint, e l'en brisa abilitê par user la funziòun ed recópper ed password par evitèr di abûs.",
'accountcreated'       => 'Et criê un nôv account',

# Edit pages
'summary'          => "Mutîv d'al cambiamèint:",
'minoredit'        => "Còst cambiamèint ché l'é un gnînt in tót",
'watchthis'        => "Tîn a drê a c'la pàgina chè",
'savearticle'      => 'Salva',
'showpreview'      => 'Anteprémma',
'showdiff'         => 'Guèrda al differèinzi',
'anoneditwarning'  => "'''Attenziòun:''' An sîv ménga vgnû dèinter. Al vòster indirézz IP al vrà signê in d'la stòria d'i cambiamèint ed sta pagina chè..",
'anontalkpagetext' => "----''Sta chè l'éla pàgina ed discussiòun d'un utèint anònim c'al n'à brisa criê un sô account o c'an l'usa ménga. Bsògna quindi usêr al sô indirézz IP par identifichèrel. L'istèss indirézz IP al pôl èsser usê da di mòndi utèint. Se sèt un utèint anònim e pèinset c'a-t in sun stèdi fâti di cummèint irrilevànt, per piasér [[Special:UserLogin|criêt un account o fê al log-in]] par evitèr confusiòuni futuri cun di èter utèint anònim.''",
'editing'          => 'Cambiamèint ed $1',
'yourdiff'         => 'Differèinzi',
'templatesused'    => 'Modêl usèdi in sta pàgina:',

# Search results
'searchhelp-url' => 'Help:Introduzione',

# Preferences page
'mypreferences' => 'AL mê preferèinzi',

# Recent changes
'recentchanges' => 'Ûltem cambiamèint',
'diff'          => 'diferèinzi',
'hist'          => 'stôria',

# Recent changes linked
'recentchangeslinked' => 'Mudéffic curelèdi',

# Upload
'upload'            => 'Carghèr un file',
'filedesc'          => "Ugêt d'al cambiamèint",
'fileuploadsummary' => "Ugêt d'al cambiamèint:",

# Special:ListFiles
'listfiles_size' => 'Dimensiòun (bytes)',

# Random page
'randompage' => 'Una pàgina a chès',

# Miscellaneous special pages
'move' => 'Môv',

# Special:Log
'specialloguserlabel' => 'Utèint:',

# Special:AllPages
'allpages' => 'Tôt al pàgin',

# Special:Log/newusers
'newuserlogpage'          => 'Regestér di nōv utèint',
'newuserlog-create-entry' => 'Un utèint nōv',

# Watchlist
'watchlist'     => 'Al còsi ca guèrd',
'watch'         => 'Tîn a drê',
'watchthispage' => "Tîn a drê a c'la pàgina chè",

# Delete
'excontent'         => "al cointgnû l'éra: '$1'",
'excontentauthor'   => "al cointgnû l'éra: '$1' (e l'ónic cuntribudôr l'éra '[[Special:Contributions/$2|$2]]')",
'confirmdeletetext' => "Stèt per scanzlèr 'na pàgina o n'imàgin, insìmma a tòt la sô crunolugî dal database.
Cunfermèr per piasèr ca saîv quàl che stèv par fêr, ca capîv al pussìbil counseguèinzi e ca stèv facènd quàst in confurmitê cun [[{{MediaWiki:Policy-url}}]].",
'deletedtext'       => '"<nowiki>$1</nowiki>" l\'è stê scanzlê.
Guèrda $2 par vèdder la lésta d\'al pàgin ch\'i sun stèdi scanzlèdi di recèint.',
'deletedarticle'    => 'scanzlê "[[$1]]"',
'dellogpage'        => 'Regestér dal scanzladûri',
'deletionlog'       => 'regéster dal scanzladûri',

# Contributions
'mycontris' => 'I mê cuntribùdi',

# What links here
'whatlinkshere' => 'I pùnten chè',

# Block/unblock
'blocklink'    => 'blòchel',
'contribslink' => "còl ch'l'à scrét",

# Move page
'1movedto2'   => "[[$1]] l'è stê mòs a [[$2]]",
'movelogpage' => 'Regestér di muvimèint',

# Special:NewFiles
'ilsubmit' => 'Zerca',

# Special:SpecialPages
'specialpages' => 'Pàgin specièli',

);

==> mediawiki-1.16.1.tar.gz: mediawiki-1.16.1/languages/messages/MessagesEml.php <==
<?php
/** Emiliano-Romagnolo (Emiliàn e rumagnòl)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ottaviano II
 * @author Timichal
 * @author Tèstaquêdra
 */

$fallback = 'it';

$messages = array(
# Dates
'sunday'    => 'Dmànga',
'monday'    => 'Lonedè',
'tuesday'   => 'Martedè',
'wednesday' => 'Merculdè',
'thursday'  => 'Giuvidè',
'friday'    => 'Venerdè',
'saturday'  => 'Sâbet',
'january'   => 'Znèr',
'february'  => 'Febrèr',
'march'     => 'Mèrz',
'april'     => 'Avrîl',
'june'      => 'Zógn',
'july'      => 'Lój',
'august'    => 'Agòst',
'september' => 'Setàmber',
'october'   => 'Utóber',
'november'  => 'Nuvàmber',
'december'  => 'Dzèmber',
'may'       => 'Mâz',

'mytalk' => 'I mê discussiòun',

# Cologne Blue skin
'qbspecialpages' => 'Pagini specièli',

'returnto'         => 'Tórna a $1.',
'help'             => 'Per quî rivê da pôch',
'history_short'    => 'Stôria',
'printableversion' => 'Versiòun stampàbil',
'permalink'        => 'Link permanèint',
'edit'             => 'Mudifichèr',
'delete'           => 'Dscanzèla',
'protect'          => 'Prutèzz',
'specialpage'      => 'Pàgina specièla',
'talk'             => 'Discussiòun',
'jumptosearch'     => 'Zerca',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'     => 'Fât e prugèt ed tót',
'currentevents-url' => 'Project:Prugèt_ed_tót',
'helppage'          => 'Help:Introduzione',
'portal'            => 'Discóter e quistiunêr',
'portal-url'        => 'Project:Bar',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Artéccol',
'nstab-template' => 'Modèl',

# Login and logout pages
'logouttext'           => "'''Adèsa s'et discunnês.'''

Putiv cuntinuèr ad usèr {{SITENAME}} anonimamèint, o putiv cunnètterv dòp cun al stèss nàmm o cun un èter.
Nutêv ca alcuni pàgini i putrèbber cuntinuèr a cràdder ca vueter a-sîv discunnès, finchè non purghê la cache dal vòster browser.",
'userlogin'            => 'Entrèr / Argistrères',
'logout'               => 'va fôra',
'userlogout'           => 'Va fôra',
'userexists'           => "Al nòmm ch'èt scélt l'è stê bèle usê: càten un èter, per piasêr.",
'loginsuccess'         => "'''Adèsa sèt cunês in {{SITENAME}} cun al nàmm d'utèint \"\$1\".'''",
'wrongpassword'        => "La password ch'et méss l'è sbajèda. Pròva ancàrra.",
'blocked-mailpassword' => "Al tô indirézz IP l'an pôl più feèr di cambiamèint, e l'en brisa abilitê par user la funziòun ed recópper ed password par evitèr di abûs.",
'accountcreated'       => 'Et criê un nôv account',

# Edit pages
'summary'          => "Mutîv d'al cambiamèint:",
'minoredit'        => "Còst cambiamèint ché l'é un gnînt in tót",
'watchthis'        => "Tîn a drê a c'la pàgina chè",
'savearticle'      => 'Salva',
'showpreview'      => 'Anteprémma',
'showdiff'         => 'Guèrda al differèinzi',
'anoneditwarning'  => "'''Attenziòun:''' An sîv ménga vgnû dèinter. Al vòster indirézz IP al vrà signê in d'la stòria d'i cambiamèint ed sta pagina chè..",
'anontalkpagetext' => "----''Sta chè l'éla pàgina ed discussiòun d'un utèint anònim c'al n'à brisa criê un sô account o c'an l'usa ménga. Bsògna quindi usêr al sô indirézz IP par identifichèrel. L'istèss indirézz IP al pôl èsser usê da di mòndi utèint. Se sèt un utèint anònim e pèinset c'a-t in sun stèdi fâti di cummèint irrilevànt, per piasér [[Special:UserLogin|criêt un account o fê al log-in]] par evitèr confusiòuni futuri cun di èter utèint anònim.''",
'editing'          => 'Cambiamèint ed $1',
'yourdiff'         => 'Differèinzi',
'templatesused'    => 'Modêl usèdi in sta pàgina:',

# Search results
'searchhelp-url' => 'Help:Introduzione',

# Preferences page
'mypreferences' => 'AL mê preferèinzi',
'yourrealname'  => 'Al tô vér nàmm:',
'yourlanguage'  => 'Léngua:',

# Recent changes
'recentchanges' => 'Ûltem cambiamèint',
'diff'          => 'diferèinzi',
'hist'          => 'stôria',

# Recent changes linked
'recentchangeslinked'         => 'Mudéffic curelèdi',
'recentchangeslinked-feed'    => 'Mudéffic curelèdi',
'recentchangeslinked-toolbox' => 'Mudéffic curelèdi',

# Upload
'upload'            => 'Carghèr un file',
'filedesc'          => "Ugêt d'al cambiamèint",
'fileuploadsummary' => "Ugêt d'al cambiamèint:",

# Special:ListFiles
'listfiles_size' => 'Dimensiòun (bytes)',

# Random page
'randompage' => 'Una pàgina a chès',

# Miscellaneous special pages
'move' => 'Môv',

# Special:Log
'specialloguserlabel' => 'Utèint:',

# Special:AllPages
'allpages' => 'Tôt al pàgin',

# Special:Log/newusers
'newuserlogpage'          => 'Regestér di nōv utèint',
'newuserlog-create-entry' => 'Un utèint nōv',

# Watchlist
'watchlist'     => 'Al còsi ca guèrd',
'watch'         => 'Tîn a drê',
'watchthispage' => "Tîn a drê a c'la pàgina chè",

# Delete
'excontent'         => "al cointgnû l'éra: '$1'",
'excontentauthor'   => "al cointgnû l'éra: '$1' (e l'ónic cuntribudôr l'éra '[[Special:Contributions/$2|$2]]')",
'confirmdeletetext' => "Stèt per scanzlèr 'na pàgina o n'imàgin, insìmma a tòt la sô crunolugî dal database.
Cunfermèr per piasèr ca saîv quàl che stèv par fêr, ca capîv al pussìbil counseguèinzi e ca stèv facènd quàst in confurmitê cun [[{{MediaWiki:Policy-url}}]].",
'deletedtext'       => '"<nowiki>$1</nowiki>" l\'è stê scanzlê.
Guèrda $2 par vèdder la lésta d\'al pàgin ch\'i sun stèdi scanzlèdi di recèint.',
'deletedarticle'    => 'scanzlê "[[$1]]"',
'dellogpage'        => 'Regestér dal scanzladûri',
'deletionlog'       => 'regéster dal scanzladûri',

# Contributions
'mycontris' => 'I mê cuntribùdi',

# What links here
'whatlinkshere' => 'I pùnten chè',

# Block/unblock
'blocklink'    => 'blòchel',
'contribslink' => "còl ch'l'à scrét",

# Move page
'1movedto2'   => "[[$1]] l'è stê mòs a [[$2]]",
'movelogpage' => 'Regestér di muvimèint',

# Special:NewFiles
'ilsubmit' => 'Zerca',

# Special:SpecialPages
'specialpages' => 'Pàgin specièli',

);
